@@ -9,9 +9,13 @@
     ## consistent results with coef.rda and vegan 2.4
     if (ncol(u))
         u <- sqrt(object$rowsum) * u
+    ## scores.cca uses na.predict and may add missing NA rows to u,
+    ## but Q has no missing cases
+    if (nrow(Q$qr) < nrow(u) && inherits(object$na.action, "exclude"))
+        u <- u[-object$na.action,, drop=FALSE]
     b <- qr.coef(Q, u)
     if (norm)
-        b <- sqrt(colSums(qr.X(object$CCA$QR)^2)) * b
+        b <- sqrt(colSums(qr.X(Q)^2)) * b
     b
 }
 
